@@ -38,6 +38,8 @@ AAptInterface::AAptInterface(QObject* parent = 0) : QObject(parent)
 	iNumSelectedPackages = 0;
 	iErrorDone = false;
 	iNeedRepoRefresh = false;
+	iNeedListRefresh = true;
+	iNeedDateRefresh = true;
 
 	iProcAptGetUpdate = new QProcess(this);
 	iProcAptGetSimulate = new QProcess(this);
@@ -236,10 +238,11 @@ bool AAptInterface::startAptGetUpdate()
 
 	if( !this->writeRepositories() )
 		return false;
+	iNeedListRefresh = true;
 
 	if( iUiDimmer ) {
 		iUiDimmer->setProgress(0);
-		iUiDimmer->updateText("Updating catalogs");		
+		iUiDimmer->updateText("Updating catalogs");
 	}
 
 	iCatalogCounter = 0;
@@ -303,13 +306,15 @@ bool AAptInterface::startAptGetInstall()
 	if( iProcessPackages.count()==0 )
 		return false;
 
+	iNeedListRefresh = true;
+
 	iProcAptGetInstallOutput.clear();
 
 	qDebug() << "running apt-get install";
 
 	QString runBinary = "/usr/bin/apt-get";
 	QStringList runParameters;
-	runParameters << "-qy" << "--allow-unauthenticated";
+	runParameters << "-qy" << "--allow-unauthenticated" << "-o" << "DPkg::options::=--force-confnew";
 	if( iSettings->qsettings()->value("enable_autoremove", false).toBool() )
 		runParameters << "--auto-remove";
 	runParameters << "install";
@@ -344,6 +349,7 @@ bool AAptInterface::startAptGetInstall()
 		if( https_proxy != "" )
 			env.insert("https_proxy", https_proxy);
 	}
+	env.insert("DEBIAN_FRONTEND", "noninteractive");
 	iProcAptGetUpdate->setProcessEnvironment(env);
 
 	logToFile( runBinary + " " + runParameters.join(" ") );
@@ -380,6 +386,10 @@ QString AAptInterface::setQProcessErrorMessage(QProcess::ProcessError error)
 		return "Process crashed";
 	else if( error == QProcess::ReadError )
 		return "QProcess read error";
+	else if( error == QProcess::WriteError )
+		return "QProcess write error";
+	else if( error == QProcess::Timedout )
+		return "QProcess timeout error";
 	else if( error == QProcess::UnknownError )
 		return "QProcess unknown error";
 
@@ -452,7 +462,7 @@ QString AAptInterface::finishProcessCommonErrorMessages(QByteArray& output)
 	} else if( output.contains("E: Couldn't find package") ) {
 		msg = "Missing package, see the log for details - Your catalogs might be out of date";
 	} else if( output.contains("E: Broken packages") ) {
-		msg = "Your system has broken packages, see the log for details";
+		msg = "Your system has broken packages or you are trying to install conflicting packages. See the log for details.";
 	} else if( output.contains("E: Handler silently failed") ) {
 		msg = "Handler silently failed - This can happen if you try to install from the forbidden user/hidden category";
 	} else if( iTerminated ) {
@@ -463,6 +473,8 @@ QString AAptInterface::finishProcessCommonErrorMessages(QByteArray& output)
 		msg = "Your system has partially installed or broken packages. You'll have to fix this manually. Try dpkg --configure -a";
 	} else if( output.contains("dpkg: error processing") || output.contains("Errors were encountered while processing:") ) {
 		msg = "dpkg reported errors while processing a package - see the log for details";
+	} else if( output.contains("E: Unmet dependencies") ) {
+		msg = "Some of your packages have unmet dependencies which could not be fixed. See the log for details.";
 	}
 
 	return msg;
@@ -747,6 +759,17 @@ void AAptInterface::uiUpdaterAptGetInstall()
 			pkgname = "";
 			update = true;
 		}
+
+		/*	// this does not seem to work, dpkg always dies first
+		if( lines.at(i).startsWith("***") && lines.at(i).contains("(Y/I/N/O/D/Z)") ) {
+			if( iMainWindow->confirmDialog("Overwrite configuration file?","la la la") )
+			{
+				iProcAptGetInstall->write("Y\n");
+			} else {
+				iProcAptGetInstall->write("N\n");
+			}
+		}
+		*/
 	}
 
 	if( update && iUiDimmer && iUiDimmer->busy() ) {
@@ -910,6 +933,8 @@ bool AAptInterface::writeRepositories()
 	return true;
 #endif
 
+	iNeedListRefresh = true;
+
 	QFile own("/root/.fapman/repos.list");
 	if( own.open(QIODevice::WriteOnly | QIODevice::Text ) )
 	{
@@ -1000,6 +1025,14 @@ void AAptInterface::startPkgListRead()
 	logToFile( QString("Start reading package lists") );
 	qDebug() << "reading package list files";
 
+	if( !iNeedListRefresh ) {
+		qDebug() << "no need to refresh package lists";
+		logToFile( QString("No need to read package lists") );
+		communicateStatusToUi(true, "Operation finished", "Package data already up to date");
+		runNext();
+		return;
+	}
+
 	if( iUiDimmer ) {
 		iUiDimmer->updateText("Reading package lists<br>");
 		iUiDimmer->setProgress(0);
@@ -1092,8 +1125,13 @@ void AAptInterface::startPkgListRead()
 							exists=0;
 							iPackagesAvailable.insert(newpkg->name(), newpkg);
 						} else {
-							if( newpkg->version() == exists->version() )
+							if( newpkg->version() == exists->version() ) {
 								exists->addRepository( currentRepo );
+								if( newpkg->fullFileNames().count()>0 )
+									exists->addFullFileName( newpkg->fullFileNames().at(0) );
+								else
+									exists->addFullFileName("unknown_dir/unknown_filename");
+							}
 							delete newpkg;
 							newpkg=0;
 						}
@@ -1168,6 +1206,8 @@ void AAptInterface::startPkgListRead()
 
 	communicateStatusToUi(true, "Operation finished", "Package data read");
 	iCanCancel = false;
+	iNeedListRefresh = false;
+	iNeedDateRefresh = true;
 	runNext();
 }
 
@@ -1230,7 +1270,7 @@ bool AAptInterface::processPackageDataLine(Package*& pkg, QByteArray& line)
 	}
 	else if( line.startsWith("Filename: ") )
 	{
-		pkg->setFileNameFull( line.mid(10) );
+		pkg->addFullFileName( line.mid(10) );
 	}
 	else if( line.startsWith("Size: ") )
 	{
@@ -1244,6 +1284,14 @@ bool AAptInterface::processPackageDataLine(Package*& pkg, QByteArray& line)
 	{
 		pkg->setMaemoDisplayName( QString::fromUtf8(line.mid(20)) );
 	}
+	else if( line.startsWith("Depends: ") )
+	{
+		pkg->setDepends( line.mid(9) );
+	}
+	else if( line.startsWith("Conflicts: ") )
+	{
+		pkg->setConflicts( line.mid(11) );
+	}
 
 	if( iMultiLine == MultiLineDesc ) {
 		if( (line.startsWith(' ') || line.startsWith('\t')) && line.trimmed()!="" ) {
@@ -1384,6 +1432,15 @@ void AAptInterface::startFetchDates()
 	logToFile( QString("Start fetching package dates") );
 	qDebug() << "start fetching package dates";
 
+	if( !iNeedDateRefresh ) {
+		qDebug() << "no need to fetch dates";
+		logToFile( QString("No need to fetch dates") );
+		communicateStatusToUi(true, "Operation finished", "Date information already up to date");
+		runNext();
+		return;
+	}
+	iNeedListRefresh = true;
+
 	if( iUiDimmer ) {
 		iUiDimmer->updateText("Reading date cache");
 		iUiDimmer->setProgress(0);
@@ -1411,11 +1468,12 @@ void AAptInterface::startFetchDates()
 		if( !i.value()->date().isValid() && i.value()->section().startsWith("user/") && !i.value()->isBlacklisted() )
 		{
 			Repository* repo = 0;
-			for( int x=0; x<i.value()->repositories().count(); x++ )
+			for( int x=0; x<i.value()->repositories().count(); x++ ) {
 				if( i.value()->repositories().at(x) && i.value()->repositories().at(x)->url().startsWith("http://repository.maemo.org") )
 				{
-				repo = i.value()->repositories().at(x);
-				break;
+					repo = i.value()->repositories().at(x);
+					break;
+				}
 			}
 			if( repo ) {
 				fetchable.insert(i.value()->name(), i.value());
@@ -1441,20 +1499,24 @@ void AAptInterface::startFetchDates()
 			updProgress=0;
 		}
 
-		if( !fe.value()->date().isValid() && fe.value()->section().startsWith("user/") )
+		if( !fe.value()->date().isValid() && fe.value()->section().startsWith("user/") && !fe.value()->isBlacklisted() )
 		{
 			QString url;
 			Repository* repo = 0;
-			for( int x=0; x<fe.value()->repositories().count(); x++ )
+			QString fullFilename = "unknown_filename";
+			for( int x=0; x<fe.value()->repositories().count(); x++ ) {
 				if( fe.value()->repositories().at(x) && fe.value()->repositories().at(x)->url().startsWith("http://repository.maemo.org") )
 				{
-				repo = fe.value()->repositories().at(x);
-				break;
+					repo = fe.value()->repositories().at(x);
+					if( fe.value()->fullFileNames().count()>x )
+						fullFilename = fe.value()->fullFileNames().at(x);
+					break;
+				}
 			}
 
 			if( repo )
 			{
-				url = repo->url() + repo->dir() + fe.value()->fileNameFull();
+				url = repo->url() + repo->dir() + fullFilename + "#" + fe.value()->name();
 
 				//qDebug() << "getting date for" << fe.value()->name();
 				//qDebug() << url;
@@ -1472,8 +1534,10 @@ void AAptInterface::startFetchDates()
 					}
 				}
 
-				if( iDateRequestsReceived>0 && iNetworkError != QNetworkReply::NoError ) {
-					qDebug() << "network error" << iNetworkError;
+				if( iDateRequestsReceived>0 && iNetworkError != QNetworkReply::NoError &&
+					iNetworkError != QNetworkReply::QNetworkReply::ContentAccessDenied && iNetworkError != QNetworkReply::QNetworkReply::ContentNotFoundError )
+				{
+					qDebug() << "fatal network error, aborting fetch";
 					break;
 				} else {
 					nam->head(r);
@@ -1496,10 +1560,11 @@ void AAptInterface::startFetchDates()
 	}
 	delete nam;
 
-	if( iNetworkError != QNetworkReply::NoError )
+	if( iDateRequestsReceived>0 && iNetworkError != QNetworkReply::NoError &&
+		iNetworkError != QNetworkReply::QNetworkReply::ContentAccessDenied && iNetworkError != QNetworkReply::QNetworkReply::ContentNotFoundError )
 	{
 		// don't stop on this error, only inform the user
-		iMainWindow->notifyDialog("Network error", "There was a network error while fetching date information");
+		iMainWindow->notifyDialog("Network error", "There was a network error while fetching date information, the fetch was aborted");
 	}
 
 	if( iTerminated ) {
@@ -1521,7 +1586,7 @@ void AAptInterface::startFetchDates()
 
 	logToFile( QString("Finished fetching package dates") );
 
-	if( fetchable.count()>0 ) {
+	if( fetchable.count()>0 || !dateCacheExists() ) {
 		iUiDimmer->updateText("Writing date cache");
 		QApplication::processEvents();
 		writeDateCache();
@@ -1534,6 +1599,8 @@ void AAptInterface::startFetchDates()
 	}
 
 	communicateStatusToUi(true, "Operation finished", "Package dates fetched");
+	iNeedDateRefresh = false;
+	iNeedListRefresh = false;
 	runNext();
 }
 
@@ -1544,23 +1611,26 @@ void AAptInterface::dateFetchNetworkReply(QNetworkReply* reply)
 	//qDebug() << "reply" << reply->header(QNetworkRequest::LastModifiedHeader).toDateTime();
 	iNetworkError = reply->error();
 
-	if( reply->header(QNetworkRequest::LastModifiedHeader).toDateTime().isValid() &&
-		iNetworkError == QNetworkReply::NoError)
+	if( reply->error() == QNetworkReply::NoError && reply->header(QNetworkRequest::LastModifiedHeader).toDateTime().isValid() )
 	{
-		QString path = reply->url().path();
-		int pos = path.lastIndexOf('/');
-		int pos2 = path.indexOf('_', pos);
-		if( pos!=-1 && pos2!=-1 ) {
-			QString pkgname = path.mid(pos+1,pos2-pos-1);
-			Package* pkg = iPackagesAvailable.value(pkgname, 0);
-			if( pkg ) {
-				pkg->setDate( reply->header(QNetworkRequest::LastModifiedHeader).toDateTime() );
-			}
+		QString pkgname = reply->url().fragment();
+		//qDebug() << pkgname;
+
+		if( pkgname.isEmpty() )
+			qDebug() << "warning: empty packagename in reply";
+
+		Package* pkg = iPackagesAvailable.value(pkgname, 0);
+		if( pkg ) {
+			pkg->setDate( reply->header(QNetworkRequest::LastModifiedHeader).toDateTime() );
+		} else {
+			qDebug() << "warning: unknown packagename in reply:" << pkgname;
 		}
 	}
 
-	if( iNetworkError != QNetworkReply::NoError )
+	if( reply->error() != QNetworkReply::NoError ) {
+		qDebug() << reply->error() << reply->errorString();
 		iDateRequestErrors++;
+	}
 	reply->deleteLater();
 }
 
