@@ -77,9 +77,10 @@ void dimmer::paintEvent(QPaintEvent *)
 			iProgress = 100;
 
 		painter.setBrush( QApplication::palette().color(QPalette::Window) );
+		painter.setPen( dim );
 		painter.drawRect(rect().left()+30, rect().bottom()-30, rect().right()-rect().left()-60, 10 );
 		painter.setBrush( QApplication::palette().color(QPalette::Highlight) );
-		painter.setPen(Qt::NoPen);
+		painter.setPen( QApplication::palette().color(QPalette::Highlight) );
 		int pw = ( rect().right()-rect().left()-60 ) * iProgress / 100;
 		painter.drawRect(rect().left()+30, rect().bottom()-30, pw, 10 );
 	}
@@ -107,9 +108,10 @@ void dimmer::orientationChanged()
 
 void dimmer::dim(QString title, QString message)
 {
+	QString colorname = QApplication::palette().color(QPalette::BrightText).name();
 	iTitle = title;
 	iBusy = true;
-	iLabel->setText("<font color=\"white\"><b><u>" + iTitle + "</u></b><br><br>" + message + "</font>");
+	iLabel->setText("<font color=\"" + colorname + "\"><b><u>" + iTitle + "</u></b><br><br>" + message + "</font>");
 	iProgress = -1;
 	iAnim = 0;
 	iAnimDir = 1;
@@ -120,7 +122,8 @@ void dimmer::dim(QString title, QString message)
 
 void dimmer::updateText(QString message)
 {
-	iLabel->setText("<font color=\"white\"><b><u>" + iTitle + "</u></b><br><br>" + message + "</font>");
+	QString colorname = QApplication::palette().color(QPalette::BrightText).name();
+	iLabel->setText("<font color=\"" + colorname + "\"><b><u>" + iTitle + "</u></b><br><br>" + message + "</font>");
 }
 
 void dimmer::setProgress(int p_)
