@@ -42,6 +42,7 @@
 #include "help.h"
 #include "settings.h"
 #include "logview.h"
+#include "rotatingbackground.h"
 
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -56,8 +57,12 @@ MainWindow::MainWindow(QWidget *parent) :
 	iWinRepoView = new RepoView(this);
 	iWinRepoView->setAptInterface(iAptInterface);
 	iSettings = new Settings(this);
+	iSettings->setAptInterface(iAptInterface);
+	iWinPackageView->setSettings(iSettings);
 	iAptInterface->setSettings(iSettings);
 
+	iWinPackageView->setSortOrder( (PackageView::sortOrder)iSettings->qsettings()->value("default_sort_order",0).toInt() );
+
 #ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	if( !iSettings->qsettings()->value("disable_autorotation",false).toBool() ) {
@@ -80,6 +85,44 @@ MainWindow::MainWindow(QWidget *parent) :
 	QFile logfile(KLogFileName);
 	logfile.remove();
 
+	ui->centralWidget->loadWallpaper();
+
+	QString stylesheet_mainscreen =
+			"QPushButton {"
+			"border-radius: 16px;"
+			"border-width: 1px;"
+			"border-color: palette(light);"
+			"border-style: outset;"
+			"padding-right: 10px;"
+			"padding-left: 10px;"
+			"color: palette(buttontext);"
+			"background: rgba(255,255,255,80);"
+			"}"
+			"QPushButton:pressed {"
+			"border-style: inset;"
+			"background-color: rgba(255,255,255,150);"
+			"}";
+
+	if( ((QApplication*)QApplication::instance())->styleSheet().isEmpty() )
+	{
+		QString stylesheet_file;
+		QFile f("/root/.fapman/style.css");
+		if( f.open(QIODevice::ReadOnly | QIODevice::Text ) )
+		{
+			while(!f.atEnd()) {
+				stylesheet_file += f.readLine().trimmed();
+			}
+			f.close();
+		}
+
+		if( stylesheet_file.isEmpty() ) {
+			ui->centralWidget->setStyleSheet(stylesheet_mainscreen);
+		} else {
+			((QApplication*)QApplication::instance())->setStyleSheet(stylesheet_file);
+		}
+	}
+
+
 	/*
 	// does not work
 
@@ -92,6 +135,8 @@ MainWindow::MainWindow(QWidget *parent) :
 	QDBusInterface net(service, path, service, conn, this);
 	net.call(method,"[ANY]",0);
 	*/
+
+	resetIdlingTime();
 }
 
 MainWindow::~MainWindow()
@@ -134,10 +179,49 @@ void MainWindow::on_btnUpdate_clicked()
 	iAptInterface->run(iDimmer);
 }
 
+#ifdef Q_WS_MAEMO_5
+int MainWindow::top_application()
+{
+	show();
+	activateWindow();
+	raise();
+	return 0;
+}
+#endif
+
+void MainWindow::dateFetchAsk()
+{
+	if( !iSettings->qsettings()->value("firstrun_asked_fetch_dates",false).toBool() &&
+		!iSettings->qsettings()->value("fetch_dates",false).toBool() )
+	{
+		iSettings->qsettings()->setValue("firstrun_asked_fetch_dates", true);
+		ConfirmDialog d(true, this);
+		d.setText("Fetch date information?","Enable date information fetching for packages? You have to enable it in order to be "
+				  "able to sort packages by date. The first fetch can be slow but the dates are cached for later use. You can later "
+				  "change this selection from the options menu.");
+		if( d.exec() )
+			iSettings->qsettings()->setValue("fetch_dates", true);
+	}
+	if( iSettings->qsettings()->value("fetch_dates",false).toBool() )
+	{
+		iSettings->qsettings()->setValue("firstrun_asked_fetch_dates", true);	// don't ask if the option has already been enabled
+		if( !iAptInterface->dateCacheExists() )
+		{
+			ConfirmDialog d(false, this);
+			d.setText("Notice","Date information will be fetched only for packages from maemo.org and only for user categories.");
+			d.exec();
+		}
+		iAptInterface->addQueuedOperation(AAptInterface::ModeFetchDates);
+	}
+}
+
 void MainWindow::on_btnListInstallable_clicked()
 {
 	//install
 
+	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-15*60) )
+		iAptInterface->setNeedListRefresh(true);
+
 	iWinPackageView->setStatFilter( Package::PkgStatNotInstalled );
 
 	if( iAptInterface->needRepoRefresh() ) //&& !iSettings->qsettings()->value("never_auto_update", false).toBool() )
@@ -148,16 +232,7 @@ void MainWindow::on_btnListInstallable_clicked()
 	iNextOperation = OpOpenPkgView;
 	iAptInterface->addQueuedOperation(AAptInterface::ModeReadPackages);
 
-	if( iSettings->qsettings()->value("fetch_dates",false).toBool() )
-	{
-		if( !iAptInterface->dateCacheExists() )
-		{
-			ConfirmDialog d(false, this);
-			d.setText("Notice","Date information will be fetched only for packages from maemo.org and only for user categories.");
-			d.exec();
-		}
-		iAptInterface->addQueuedOperation(AAptInterface::ModeFetchDates);
-	}
+	dateFetchAsk();
 
 	iAptInterface->run(iDimmer);
 }
@@ -166,6 +241,9 @@ void MainWindow::on_btnUpgrade_clicked()
 {
 	// upgrade
 
+	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-15*60) )
+		iAptInterface->setNeedListRefresh(true);
+
 	iWinPackageView->setStatFilter( Package::PkgStatUpgradeable );
 
 	if( iAptInterface->needRepoRefresh() ) //&& !iSettings->qsettings()->value("never_auto_update", false).toBool() )
@@ -176,16 +254,7 @@ void MainWindow::on_btnUpgrade_clicked()
 	iNextOperation = OpOpenPkgView;
 	iAptInterface->addQueuedOperation(AAptInterface::ModeReadPackages);
 
-	if( iSettings->qsettings()->value("fetch_dates",false).toBool() )
-	{
-		if( !iAptInterface->dateCacheExists() )
-		{
-			ConfirmDialog d(false, this);
-			d.setText("Notice","Date information will be fetched only for packages from maemo.org and only for user categories.");
-			d.exec();
-		}
-		iAptInterface->addQueuedOperation(AAptInterface::ModeFetchDates);
-	}
+	dateFetchAsk();
 
 	iAptInterface->run(iDimmer);
 }
@@ -194,18 +263,22 @@ void MainWindow::on_btnListInstalled_clicked()
 {
 	//remove
 
+	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-15*60) )
+		iAptInterface->setNeedListRefresh(true);
+
 	iWinPackageView->setStatFilter( Package::PkgStatInstalled );
 
-	// don't require this for package removal, even though other operations can be performed
-	// through the same view
-	//if( iAptInterface->needRepoRefresh() )
-	//	iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetUpdate);
+	// should not require this on remove?
+	if( iAptInterface->needRepoRefresh() ) //&& !iSettings->qsettings()->value("never_auto_update", false).toBool() )
+		iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetUpdate);
 
 	busyDialog(true, tr("Operation in progress"), tr("Reading package lists"));
 
 	iNextOperation = OpOpenPkgView;
 	iAptInterface->addQueuedOperation(AAptInterface::ModeReadPackages);
 
+	dateFetchAsk();
+
 	iAptInterface->run(iDimmer);
 }
 
@@ -247,11 +320,20 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 			}
 		}
 
+		int total_dl_size = 0;
+		for( int i=0; i<inst.count(); i++ ) {
+			Package* pkg = iAptInterface->packagesAvailable()->value(inst.at(i),0);
+			if( pkg ) {
+				total_dl_size += pkg->size()/1024;
+			}
+		}
+
 		QString pkglist;
-		pkglist = QString("<b>The following operations will be performed:</b><br>" \
+		pkglist = QString("<b>The following operations will be performed:</b><br>"
 				  "%1 to install/upgrade, %2 to remove<br>").arg(inst.count()).arg(remv.count());
+		if( inst.count()>0 )
+			pkglist += QString("Total download size: %L1 kB<br>").arg(total_dl_size);
 		bool mismatch = false;
-		int total_inst_size = 0;
 
 		if( remv.count()>0 ) {
 			pkglist += "<br><b><u>REMOVE:</u></b><br><font size=\"-1\">";
@@ -298,7 +380,6 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 				}
 				if( pkg && pkg->size()>0 ) {
 					pkglist += QString(" (%L1 kB)").arg(pkg->size()/1024);
-					total_inst_size += pkg->size()/1024;
 				}
 				pkglist += "<br>";
 			}
@@ -417,6 +498,13 @@ void MainWindow::notifyDialog(QString title, QString msg)
 	d.exec();
 }
 
+bool MainWindow::confirmDialog(QString title, QString msg)
+{
+	ConfirmDialog d(true, this);
+	d.setText(title, msg);
+	return d.exec();
+}
+
 void MainWindow::GdkEventIconThemeReload()
 {
 	// DOES NOT EVEN WORK (at least not reliably) - disabled from the project file
@@ -426,6 +514,7 @@ void MainWindow::GdkEventIconThemeReload()
 
 	gdk_init((int*)QApplication::argc(),(gchar***)QApplication::argv());
 
+	// taken from hildon application manager
 	GdkEventClient ev;
 	ev.type = GDK_CLIENT_EVENT;
 	ev.window = NULL;
