@@ -38,6 +38,9 @@ namespace Ui {
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
+#ifdef Q_WS_MAEMO_5
+	Q_CLASSINFO("D-Bus Interface", "org.maemo.faster_application_manager")
+#endif
 
 public:
 	enum nextOperation { OpNone, OpPromptSimulated, OpOpenPkgView };
@@ -49,14 +52,21 @@ public:
 	void closeEvent(QCloseEvent *event);
 	void GdkEventIconThemeReload();
 	void notifyDialog(QString title, QString msg);
+	bool confirmDialog(QString title, QString msg);
+	void resetIdlingTime() { iIdlingSince = QDateTime::currentDateTime(); }
 
 public slots:
 	void on_btnUpdate_clicked();
+#ifdef Q_WS_MAEMO_5
+	Q_SCRIPTABLE int top_application();
+#endif
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
+	void dateFetchAsk();
+
     Ui::MainWindow *ui;
 	AAptInterface* iAptInterface;
 	PackageView* iWinPackageView;
@@ -69,6 +79,8 @@ private:
 	bool iUpgradeAutoUpdate;
 	nextOperation iNextOperation;
 
+	QDateTime iIdlingSince;
+
 private slots:
 	void on_actionOptions_triggered();
  void on_actionView_log_triggered();
