@@ -36,17 +36,6 @@ Package::Package(QString name_, AAptInterface *apt_)
 	iPkgStatus = PkgStatUnknown;
 	iIcon = 0;
 	iBlacklist = BlacklistSelect::BlacklistNone;
-/*	//should be empty anyway
-	iIconData = "";
-	iFileNameFull = "";
-	iRepoFileName = "";
-	iDateString = "";
-	iDescriptionShort = "";
-	iDescriptionLong = "";
-	iSection = "";
-	iMaemoDisplayName = "";
-	iVersion = "";
-*/
 }
 
 Package::~Package()
@@ -66,6 +55,16 @@ QString Package::displayName()
 	return name;
 }
 
+QString Package::fileName()
+{
+	if( iFullFileNames.count()>0 ) {
+		return iFullFileNames.at(0).mid( iFullFileNames.at(0).lastIndexOf('/')+1 );
+	} else {
+		qDebug() << "Warning: package has no file name information";
+		return "unknown_filename";
+	}
+}
+
 void Package::setMarkedForOperation(operation op_)
 {
 	if( iMarkedOperation != op_ ) {
@@ -169,3 +168,45 @@ bool Package::versionCompare(QString isNewer, QString compare)
 	return false;
 }
 
+void Package::setDepends(QString depends_)
+{
+	iDepends = depends_.split(',');
+}
+
+void Package::setConflicts(QString conflicts_)
+{
+	iConflicts = conflicts_.split(',');
+}
+
+QStringList Package::depends()
+{
+	qDebug() << iName;
+	qDebug() << iDepends;
+	QStringList list;
+
+	for(int i=0; i<iConflicts.count(); i++)
+	{
+		QStringList parts = iConflicts.at(i).split('|');
+		for(int j=0; j<parts.count(); j++)
+		{
+			qDebug() << parts.at(j);
+			int pos = parts.at(j).trimmed().indexOf(' ');
+			QString s;
+			if( pos==-1 )
+				s = parts.at(j).trimmed();
+			else
+				s = parts.at(j).left(pos).trimmed();
+			list << s;
+		}
+	}
+
+	return list;
+}
+
+QStringList Package::conflicts()
+{
+	QStringList list;
+
+
+	return list;
+}
