@@ -47,11 +47,13 @@ public:
 	void setSize(int i_) { iSize=i_; }
 	void setInstalledSize(int i_) { iInstalledSize=i_; }
 	void appendIconData(QByteArray d_) { iIconData.append(d_); }
-	void setFileNameFull(QString f_) { iFileNameFull=f_; }
+	void addFullFileName(QString f_) { iFullFileNames.append(f_); }
 	void updateStatus();
 	void addRepository(Repository* r_) { iRepositories.append(r_); }
 	void setDate(QDateTime d_) { iDate=d_; }
 	void setBlacklisted(BlacklistSelect::blackList bl_) { iBlacklist=bl_; }
+	void setDepends(QString depends_);
+	void setConflicts(QString conflicts_);
 
 	void convertIcon();
 
@@ -73,13 +75,16 @@ public:
 	QString upgradeableVersion();
 	Package* availablePackage();
 	packageStatus status();
-	QString fileName() { return iFileNameFull.mid( iFileNameFull.lastIndexOf('/')+1 ); }
-	QString fileNameFull() { return iFileNameFull; }
+	QString fileName();
+	QStringList fullFileNames() { return iFullFileNames; }
 	QDateTime date() { return iDate; }
 	QList<Repository*> repositories() { return iRepositories; }
 	BlacklistSelect::blackList blacklisted() { return iBlacklist; }
 	bool isBlacklisted() { if(iBlacklist==BlacklistSelect::BlacklistNone) return false; else return true;}
 
+	QStringList depends();
+	QStringList conflicts();
+
 	static bool versionCompare(QString isNewer, QString compare);
 
 private:
@@ -97,13 +102,16 @@ private:
 	int iSize;
 	int iInstalledSize;
 	operation iMarkedOperation;
-	QString iFileNameFull;
+	QStringList iFullFileNames;
 	QDateTime iDate;
 	QList<Repository*> iRepositories;
 	BlacklistSelect::blackList iBlacklist;
 
 	QByteArray iIconData;
 	QPixmap* iIcon;
+
+	QStringList iDepends;
+	QStringList iConflicts;
 };
 
 #endif // PACKAGE_H
