@@ -144,9 +144,14 @@ PackageSelector::PackageSelector(Package* pkg, AAptInterface* apt, QWidget *pare
 	QString descLong = pkg->descLong();
 	if( descLong.length()>0 ) {
 		descLong.replace('\n',"<br>");
-		longtext += "<br><font size=\"-1\"><br>" + descLong + "</font>";
+		longtext += "<br><font size=\"-1\"><br>" + descLong + "</font><br>";
 	}
 
+
+	pkg->depends();
+	pkg->conflicts();
+
+
 	ui->label_text->setText( longtext );
 
 	if( pkg->isUpgradeable() )
