@@ -28,6 +28,7 @@
 #include "aaptinterface.h"
 #include "logview.h"
 #include "sortselector.h"
+#include "settings.h"
 
 PackageListWidgetItem::PackageListWidgetItem(Package* p_, QString name_) : QListWidgetItem(name_)
 {
@@ -47,6 +48,7 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 	bool installed = index.data(UserRoleInstalled).toBool();
 	bool upgradeable = index.data(UserRoleUpgradeable).toBool();
 	int statfilter = index.data(UserRoleCurrentStatFilter).toInt();
+	int catfilter = index.data(UserRoleCurrentCatFilter).toInt();
 	QString upg_version = index.data(UserRoleAvailVersion).toString();
 
 	painter->save();
@@ -55,8 +57,20 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 	QLinearGradient gradientBase(r.topLeft(), r.bottomLeft());
 	QColor base = option.palette.color(QPalette::Window);
 	QColor base2 = base;
-	base.setRgb( base.red()+15, base.green()+15, base.blue()+15 );
-	base2.setRgb( base2.red()-20, base2.green()-20, base2.blue()-20 );
+	int r1=base.red()+15;
+	int g1=base.green()+15;
+	int b1=base.blue()+15;
+	if( r1>255 ) r1=255;
+	if( g1>255 ) g1=255;
+	if( b1>255 ) b1=255;
+	int r2=base2.red()-20;
+	int g2=base2.green()-20;
+	int b2=base2.blue()-20;
+	if( r2<0 ) r2=0;
+	if( g2<0 ) g2=0;
+	if( b2<0 ) b2=0;
+	base.setRgb( r1, g1, b1 );
+	base2.setRgb( r2, g2, b2 );
 	gradientBase.setColorAt(0, base);
 	gradientBase.setColorAt(1, base2);
 
@@ -90,10 +104,14 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 	}
 
 	QString showVer = "";
-	if( upgradeable && statfilter==Package::PkgStatUpgradeable )
+	if( upgradeable && (statfilter==Package::PkgStatUpgradeable ||
+						(statfilter==Package::PkgStatUnknown && marked==Package::PkgOpInstallUpgrade) ||
+						(catfilter==PackageView::CatFilterAllMarked && marked==Package::PkgOpInstallUpgrade) ))
+	{
 		showVer = upg_version;
-	else
+	} else {
 		showVer = version;
+	}
 
 	int ver_w = 0;
 	if( QApplication::desktop()->width() > QApplication::desktop()->height() )
@@ -154,6 +172,8 @@ PackageView::PackageView(QWidget *parent) : QMainWindow(parent), ui(new Ui::Pack
 	this->setWindowFlags(Qt::Window);
 	this->setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
+	iSettings = 0;
+	iAptInterface = 0;
 
 	connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
 
@@ -286,10 +306,10 @@ QString PackageView::generateSortString(Package* pkg)
 		if( pkg->isUpgradeable() )
 			upg = pkg->availablePackage();
 
-		if( !upg && pkg->date().isValid() )
-			sortstr = pkg->date().toString("yyyy-MM-dd hh:mm");
+		if( (!upg && pkg->date().isValid()) || iSelectedStatFilter==Package::PkgStatInstalled )
+			sortstr = pkg->date().toString("yyyy-MM-dd hh:mm:ss");
 		else if( upg && upg->date().isValid() ) {
-			sortstr = upg->date().toString("yyyy-MM-dd hh:mm");
+			sortstr = upg->date().toString("yyyy-MM-dd hh:mm:ss");
 		} else {
 			sortstr = "";
 			iPackagesEmptySort++;
@@ -399,7 +419,10 @@ void PackageView::openWin()
 
 	if( ui->listWidget->count()>1 && iPackagesEmptySort == ui->listWidget->count() && !iSortNoticeShown ) {
 		ConfirmDialog d(false, this);
-		d.setText("Notice", "No shown packages currently have the required information for sorting by this criterion. The list is unsorted.");
+		QString msg = "No shown packages currently have the required information for sorting by this criterion. The list is unsorted.";
+		if( iSortOrder == SortDateDesc && !iSettings->qsettings()->value("fetch_dates",false).toBool() )
+			msg += " You can enable date fetching in the options menu.";
+		d.setText("Notice", msg);
 		d.exec();
 		iSortNoticeShown = true;
 	}
@@ -438,6 +461,7 @@ void PackageView::addListItem(Package* pkg_, QString listname_)
 		p->setData(UserRoleUpgradeable, pkg_->isUpgradeable());
 		p->setData(UserRoleAvailVersion, pkg_->upgradeableVersion());
 		p->setData(UserRoleCurrentStatFilter, (int)iSelectedStatFilter);
+		p->setData(UserRoleCurrentCatFilter, iSelectedCatFilter);
 
 		//qDebug()<<pkg_->name();
 
@@ -473,7 +497,6 @@ void PackageView::closeEvent(QCloseEvent *event)
 		d.setText("Returning to main menu", QString("Clear %1 package selection(s) and lose all the pending changes?").arg(iAptInterface->numSelectedPackages()));
 		if( d.exec() ) {
 			resetWindow();
-			QWidget::closeEvent(event);
 			event->accept();
 		} else {
 			event->ignore();
@@ -660,11 +683,13 @@ void PackageView::on_btn_StatusFilter_clicked()
 
 void PackageView::resetWindow()
 {
+	iMainWindow->resetIdlingTime();
+
 	iAptInterface->writeBlacklist();
 
-	iSelectedCatFilter = iDefaultCatFilter;
 	ui->btn_StatusFilter->setEnabled(true);
-	iSortOrder = SortAlpha;
+	//iSelectedCatFilter = iDefaultCatFilter;
+	//iSortOrder = SortAlpha;
 	iSortNoticeShown = false;
 
 	clearSelections();
