@@ -34,10 +34,11 @@ class AptInterface;
 class Package;
 class dimmer;
 class KeyEventGrabber;
+class Settings;
 
 enum UserRoles { UserRoleName=Qt::UserRole, UserRoleVersion, UserRoleDescShort,
 				 UserRoleMarked, UserRoleInstalled, UserRoleUpgradeable, UserRoleAvailVersion,
-				 UserRoleCurrentStatFilter };
+				 UserRoleCurrentStatFilter, UserRoleCurrentCatFilter };
 
 
 class PackageListWidgetItem : public QListWidgetItem
@@ -78,17 +79,19 @@ class PackageView : public QMainWindow
 
 public:
 
-	enum sortOrder { SortAlpha, SortSizeDesc, SortDateDesc };
+	enum sortOrder { SortAlpha, SortDateDesc, SortSizeDesc };
 
     explicit PackageView(QWidget *parent = 0);
     ~PackageView();
 	void openWin();
 	void resizeEvent(QResizeEvent* event);
 	void setAptInterface(AAptInterface* a_) { iAptInterface=a_; }
+	void setSettings(Settings* s_) { iSettings=s_; }
 	dimmer* mydimmer() { return iDimmer; }
 	void disableMenu();
 	void enableMenu();
 	void setStatFilter(Package::packageStatus f_);
+	void setSortOrder(sortOrder s_) { iSortOrder = s_; }
 	void clearSelections();
 	void setSearchText(QString text);
 
@@ -113,6 +116,10 @@ public:
 	}
 #endif
 
+	static const int CatFilterAllMarked = 0;
+	static const int CatFilterAllUser = 1;
+	static const int CatFilterBlacklisted = 16;
+
 public slots:
 	void orientationChanged();
 	void on_actionSearch_triggered();
@@ -136,14 +143,12 @@ private:
 	QBoxLayout* iPkgLayout;
 	dimmer* iDimmer;
 	QLabel* iListCoverLabel;
+	Settings* iSettings;
 
 	QStringList iCatFilterLabels;
 	QStringList iCatFilterStrings;
 	int iSelectedCatFilter;
 	int iDefaultCatFilter;
-	static const int CatFilterAllMarked = 0;
-	static const int CatFilterAllUser = 1;
-	static const int CatFilterBlacklisted = 16;
 
 	QStringList iStatFilterLabels;
 	int iSelectedStatFilter;
