@@ -20,6 +20,9 @@
 #include "settings.h"
 #include "ui_settings.h"
 #include "mainwindow.h"
+#include "aaptinterface.h"
+#include "packageview.h"
+#include "confirmdialog.h"
 
 Settings::Settings(QWidget *parent) :
     QDialog(parent),
@@ -27,6 +30,7 @@ Settings::Settings(QWidget *parent) :
 {
     ui->setupUi(this);
 
+	iAptInterface = 0;
 	iQSettings = new QSettings("/root/.fapman/settings.ini",QSettings::IniFormat);
 }
 
@@ -57,14 +61,20 @@ void Settings::openWin()
 	ui->checkBox_autoclean->setChecked( iQSettings->value("enable_autoclean", false).toBool() );
 
 	ui->checkBox_proxies->setChecked( iQSettings->value("use_proxies", false).toBool() );
-	ui->lineEdit_http_proxy->setText(iQSettings->value("http_proxy","").toString() );
-	ui->lineEdit_https_proxy->setText(iQSettings->value("https_proxy","").toString() );
+	ui->lineEdit_http_proxy->setText( iQSettings->value("http_proxy","").toString() );
+	ui->lineEdit_https_proxy->setText( iQSettings->value("https_proxy","").toString() );
+
+	ui->comboBox_sortorder->setCurrentIndex( iQSettings->value("default_sort_order",0).toInt() );
 
 	open();
 }
 
 void Settings::on_btn_OK_clicked()
 {
+	if( ui->checkBox_fetchdates->isChecked() != iQSettings->value("fetch_dates",false).toBool() && iAptInterface ) {
+		iAptInterface->setNeedListRefresh(true);
+	}
+
 	iQSettings->setValue("fetch_dates", ui->checkBox_fetchdates->isChecked() );
 	iQSettings->setValue("disable_autorotation", ui->checkBox_autorotation->isChecked() );
 	iQSettings->setValue("enable_autoremove", ui->checkBox_autoremove->isChecked() );
@@ -74,6 +84,17 @@ void Settings::on_btn_OK_clicked()
 	iQSettings->setValue("http_proxy", ui->lineEdit_http_proxy->text() );
 	iQSettings->setValue("https_proxy", ui->lineEdit_https_proxy->text() );
 
+	iQSettings->setValue("default_sort_order", ui->comboBox_sortorder->currentIndex() );
+
+	if( ui->comboBox_sortorder->currentIndex() == (int)PackageView::SortDateDesc && !ui->checkBox_fetchdates->isChecked() ) {
+		iQSettings->setValue("fetch_dates", true );
+		iAptInterface->setNeedListRefresh(true);
+
+		ConfirmDialog d(false, this);
+		d.setText("Notice","You have selected date as the default sorting criterion. Fetching dates has been automatically enabled.");
+		d.exec();
+	}
+
 #ifdef Q_WS_MAEMO_5
 	if( !iQSettings->value("disable_autorotation",false).toBool() ) {
 		dynamic_cast<MainWindow*>(this->parent())->setAttribute(Qt::WA_Maemo5AutoOrientation);
