@@ -22,6 +22,8 @@
 
 #include <QtGui>
 
+class AAptInterface;
+
 namespace Ui {
     class Settings;
 }
@@ -34,6 +36,7 @@ public:
     explicit Settings(QWidget *parent = 0);
     ~Settings();
 	void openWin();
+	void setAptInterface(AAptInterface* apt) { iAptInterface=apt; }
 
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	void open() {
@@ -58,6 +61,7 @@ protected:
 private:
     Ui::Settings *ui;
 	QSettings* iQSettings;
+	AAptInterface* iAptInterface;
 
 private slots:
 	void on_btn_OK_clicked();
